@@ -10,11 +10,11 @@ struct vector {
 
 void *vector_append(struct vector *v);
 void vector_clear(struct vector *v);
+struct vector *vector_splice_into(struct vector *src, struct vector *dst);
+struct vector *vector_concat_into(struct vector *src, struct vector *dst);
 
 struct vector files_vector;
-struct vector filtered;
 
-#define nfiles (files_vector.used)
 #define files ((struct filename *)(files_vector.buffer))
 
 #endif
